@@ -1,7 +1,7 @@
 #!/bin/sh -e
 
 # called by uscan with '--upstream-version' <version> <file>
-DIR=ncs-$2
+DIR=code_saturne-$2
 DIRTARGET=code-saturne-$2
 TAR=../code-saturne_$2.orig.tar.bz2
 
